## Install ControlFlow

Install ControlFlow with your preferred package manager:

<CodeGroup>
```bash pip
# ControlFlow requires Python 3.9 or greater
pip install -U controlflow 
```

```bash uv
# ControlFlow requires Python 3.9 or greater
uv pip install -U controlflow 
```
</CodeGroup>

## Provide an API Key

ControlFlow's default LLM is OpenAI's GPT-4o model, which provides excellent performance out of the box.
To use it, you'll need to provide an API key as an environment variable:

```bash
export OPENAI_API_KEY="your-api-key"
```